Stan Math Library: stan/math/prim/arr/fun Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

fun Directory Reference

## Files
file | dist.hpp [code]
file | dot.hpp [code]
file | dot_self.hpp [code]
file | fill.hpp [code]
file | log_sum_exp.hpp [code]
file | promote_scalar.hpp [code]
file | promote_scalar_type.hpp [code]
file | rep_array.hpp [code]
file | scaled_add.hpp [code]
file | sub.hpp [code]
file | sum.hpp [code]
file | value_of.hpp [code]
file | value_of_rec.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.